@@ -495,6 +495,8 @@ class LadonMethodInfo(object):
 		except KeyError as ke:
 			# return type must be specified.
 			raise ReturnTypeUndefined(sinfo,self._func_name)
+		# Check if the method is registered as a tasktype
+		self._tasktype = def_kw.get('tasktype',False)
 		# _rtype_doc: Initialize the return type doc-string container
 		self._rtype_doc = []
 		# overwrite the default values of user options if they are passed on via the
