@@ -78,7 +78,6 @@ def read_data_file(start_response,path_info,path_list):
 	else:
 		found = False
 		paths = map(lambda x: os.path.join(x,path_info[1:]), path_list)
-		print paths
 		for p in paths:
 			if os.path.exists(p):
 				found = True
@@ -364,7 +363,7 @@ class LadonWSGIApplication(object):
 			self.import_services(self.service_list)
 			sname,ifname,action,multipart,boundary = self.parse_environ(environ)
 			client_path = probe_client_path(environ)
-
+			query = parse_qs(environ['QUERY_STRING'])
 			if sname in self.reserved_roots:
 				if sname=='skins':
 					data = read_data_file(start_response,environ['PATH_INFO'],self.path_list)
@@ -394,7 +393,6 @@ class LadonWSGIApplication(object):
 					self.catalog_desc,charset)
 			elif sinst and not ifname:
 				content_type = 'text/html'
-				query = parse_qs(environ['QUERY_STRING'])
 				skin = query.get('skin', [None])[0]
 				output = self.generate_service_html(sinst,client_path,charset,skin)
 
@@ -402,7 +400,7 @@ class LadonWSGIApplication(object):
 				if action=='description':
 					content_type = dispatcher.iface.description_content_type()
 					service_url = client_path[0:client_path.find('/description')]
-					output += dispatcher.iface.description(service_url,charset)
+					output += dispatcher.iface.description(service_url,charset,**dict(map(lambda x: (x[0],x[1][0]), query.items())))
 				else:
 					allowed_methods = ['POST']
 					if environ['REQUEST_METHOD'] not in allowed_methods or not environ.get('CONTENT_LENGTH', ''):
