@@ -53,6 +53,16 @@ def set_logfile(logfile):
 	global cur_logfile
 	cur_logfile = logfile
 
+cur_log_maxsize = 4000000
+def set_log_maxsize(log_maxsize):
+	global cur_log_maxsize
+	cur_log_maxsize = log_maxsize
+
+cur_backup_count = 5
+def set_log_backup_count(backup_count):
+	global cur_backup_count
+	cur_backup_count = backup_count
+
 def write(msg,loglevel=3,context=None,force=False):
 	
 	"""
@@ -72,7 +82,7 @@ def write(msg,loglevel=3,context=None,force=False):
 		6 = Debug          (manual tracing)
 		7 = Trace          (trace details)
 	"""
-	global cur_loglevel,cur_logfile
+	global cur_loglevel,cur_logfile,cur_backup_count,cur_log_maxsize
 
 	if cur_loglevel<loglevel and force==False:
 		# Log level filters out this message
@@ -90,7 +100,7 @@ def write(msg,loglevel=3,context=None,force=False):
 
 	# Add the log message handler to the logger
 	if len(logger.handlers)==0:
-		handler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=4000000, backupCount=5)
+		handler = logging.handlers.RotatingFileHandler(LOG_FILENAME, maxBytes=cur_log_maxsize, backupCount=cur_backup_count)
 		formatter = logging.Formatter("%(asctime)s - %(message)s")
 		handler.setFormatter(formatter)
 		logger.addHandler(handler)
